/*** FILEHEADER ****************************************************************
 *
 *   FILENAME:    demo.h
 *   DATE:        04.08.2004
 *   AUTHOR:       (c) Christian Stadler
 *
 *   DESCRIPTION: project configuration.
 *
 ******************************************************************************/

/*** HISTORY OF CHANGE *********************************************************
 *
 *   $Log: /pic/rfm12demo/rfm12demo.h $
 * 
 * 2     1.11.10 13:42 Stadler
 * - make code compilable with C18 compiler and CCS compiler
 * 
 * 1     30.10.10 18:49 Stadler
 * - RFM12 wireless FSK transceiver module demo
 * 
 * 1     5.08.04 13:33 Stadler
 * initial creation of PIC18F4xx Demo
 *
 ******************************************************************************/

#ifndef _RFM12DEMO_H
#define _RFM12DEMO_H


/*---------------------------------------------------------------------------*/
/* Configuration for Microchip C18 Compiler                                  */
/*---------------------------------------------------------------------------*/
#if defined(__18CXX)

/* compile specific include files */
#include <p18cxxx.h>
#include <delays.h>
#include <stdio.h>
#include <usart.h>
#include <string.h>

#include "types.h"


/* configuration bits */
#pragma config OSC = HSPLL
#pragma config WDT = OFF
#pragma config LVP = ON


/*******************************************************************************
 * FUNCTION:   void delay_us(uint usec)
 * PURPOSE:    delay for the given number of microseconds
 *
 * void Delay10TCYx(unsigned char unit):
 * - Delay in multiples of 10 instructions
 * - @32MHz one instruction takes 1/32000000MHz * 4 = 125ns
 * => 10 instructions => 1.25us => 8 calls of Delay10TCYx take 10us
 ******************************************************************************/
void delay_us(uint16 usec)
{
    int i;
    
    /* 10us resolution */
    usec = usec / 10;

    for (i=0; i<usec; i++)
    {
        Delay10TCYx(8);
    }
}


/*******************************************************************************
 * FUNCTION:   void delay_ms(uint16 msec)
 * PURPOSE:    delay for the given number of miliseconds
 ******************************************************************************/
void delay_ms(uint16 msec)
{
    int i;
    
    for (i=0; i<msec; i++)
    {
        delay_us(1000);
    }
}

#endif /* #if defined(__18CXX) */




/*---------------------------------------------------------------------------*/
/* Configuration for CCS C Compiler                                          */
/*---------------------------------------------------------------------------*/
#if (defined(__PCB__) || defined(__PCH__) || defined(__PCM__))

#include <18F458.h>
#device adc=8
#use delay(clock=32000000)
#fuses NOWDT,WDT128,H4, NOPROTECT, NOOSCSEN, BROWNOUT, BORV20, NOPUT, NOCPD, STVREN, NODEBUG, LVP, NOWRT, NOWRTD, NOWRTB, NOCPB, NOWRTC, NOEBTR, NOEBTRB
#use rs232(baud=19200,parity=N,xmit=PIN_C6,rcv=PIN_C7,bits=8)

#endif /* (defined(__PCB__) || defined(__PCH__) || defined(__PCM__)) */

#endif /* #ifndef _RFM12DEMO_H */


